summaryrefslogtreecommitdiff
path: root/plugins/wimax
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2008-12-22 15:24:18 +0000
committerBill Meier <wmeier@newsguy.com>2008-12-22 15:24:18 +0000
commit9a3563e807a7caa646c79437482aed92fa12182b (patch)
treea068b3f1ae574b5a837b88e9b4b6629b4be5c709 /plugins/wimax
parent15f02081b343d595d51d5c3cd274a8f69e28bed2 (diff)
downloadwireshark-9a3563e807a7caa646c79437482aed92fa12182b.tar.gz
Fix some typos and spelling (mostly in text strings)
svn path=/trunk/; revision=27085
Diffstat (limited to 'plugins/wimax')
-rw-r--r--plugins/wimax/mac_hd_type2_decoder.c4
-rw-r--r--plugins/wimax/msg_clk_cmp.c14
-rw-r--r--plugins/wimax/msg_ulmap.c4
-rw-r--r--plugins/wimax/wimax_utils.c2
4 files changed, 12 insertions, 12 deletions
diff --git a/plugins/wimax/mac_hd_type2_decoder.c b/plugins/wimax/mac_hd_type2_decoder.c
index be613ec1e6..280d781a73 100644
--- a/plugins/wimax/mac_hd_type2_decoder.c
+++ b/plugins/wimax/mac_hd_type2_decoder.c
@@ -495,7 +495,7 @@ static hf_register_info hf[] =
{
&hf_mac_header_type_2_mimo_coef_ai,
{
- "Occurences of Antenna Index", "wmx.type2MimoCoefAi",
+ "Occurrences of Antenna Index", "wmx.type2MimoCoefAi",
FT_UINT16, BASE_DEC, NULL, WIMAX_MAC_HEADER_TYPE_2_MIMO_COEF_AI,
"", HFILL
}
@@ -519,7 +519,7 @@ static hf_register_info hf[] =
{
&hf_mac_header_type_2_dl_chan_diuc,
{
- "Prefered DIUC", "wmx.type2DlChanDiuc",
+ "Preferred DIUC", "wmx.type2DlChanDiuc",
FT_UINT16, BASE_DEC, NULL, WIMAX_MAC_HEADER_TYPE_2_DL_CHAN_DIUC,
"", HFILL
}
diff --git a/plugins/wimax/msg_ulmap.c b/plugins/wimax/msg_ulmap.c
index 30b4675064..e6905af213 100644
--- a/plugins/wimax/msg_ulmap.c
+++ b/plugins/wimax/msg_ulmap.c
@@ -1149,7 +1149,7 @@ gint AAS_UL_IE(proto_tree *uiuc_tree, const guint8 *bufptr, gint offset, gint le
XBIT(data, 7, "UL_PermBase");
XBIT(data, 8, "OFDMA symbol offset");
XBIT(data, 8, "AAS zone length");
- XBIT(data, 2, "Uplink peramble config");
+ XBIT(data, 2, "Uplink preamble config");
XBIT(data, 1, "Preamble type");
XBIT(data, 4, "Reserved");
return BIT_TO_NIB(bit);
@@ -1202,7 +1202,7 @@ gint CQICH_Alloc_IE(proto_tree *uiuc_tree, const guint8 *bufptr, gint offset, gi
XBIT(data, 2, "Zone type");
XBIT(data, 2, "Zone PRBS_ID");
if (zperm == 0 || zperm == 1) {
- XBIT(mgi, 1, "Major group indicatioon");
+ XBIT(mgi, 1, "Major group indication");
if (mgi == 1) {
/* PUSC major group bitmap*/
XBIT(data, 6, "PUSC Major group bitmap");
diff --git a/plugins/wimax/wimax_utils.c b/plugins/wimax/wimax_utils.c
index 2436e7fd5e..294eb53bf6 100644
--- a/plugins/wimax/wimax_utils.c
+++ b/plugins/wimax/wimax_utils.c
@@ -758,7 +758,7 @@ static hf_register_info hf_sfe[] =
},
{ /* 26 ARQ Block Size for Corrigendum 2 */
&hf_sfe_arq_min_block_size,
- {"ARQ Minumum Block Size", "wmx.arq.min_block_size", FT_UINT8, BASE_DEC, NULL, 0x0F, "", HFILL}
+ {"ARQ Minimum Block Size", "wmx.arq.min_block_size", FT_UINT8, BASE_DEC, NULL, 0x0F, "", HFILL}
},
{ /* 26 ARQ Block Size for Corrigendum 2 */
&hf_sfe_arq_max_block_size,
diff --git a/plugins/wimax/msg_clk_cmp.c b/plugins/wimax/msg_clk_cmp.c
index 291ff2b92c..33c935a09e 100644
--- a/plugins/wimax/msg_clk_cmp.c
+++ b/plugins/wimax/msg_clk_cmp.c
@@ -54,7 +54,7 @@ static gint hf_clk_cmp_message_type = -1;
static gint hf_clk_cmp_clock_count = -1;
static gint hf_clk_cmp_clock_id = -1;
static gint hf_clk_cmp_seq_number = -1;
-static gint hf_clk_cmp_comparision_value = -1;
+static gint hf_clk_cmp_comparison_value = -1;
static gint hf_clk_cmp_invalid_tlv = -1;
/* CLK_CMP fields display */
@@ -82,9 +82,9 @@ static hf_register_info hf_clk_cmp[] =
}
},
{
- &hf_clk_cmp_comparision_value,
+ &hf_clk_cmp_comparison_value,
{
- "Comparision Value", "wmx.clk_cmp.comparision_value",
+ "Comparison Value", "wmx.clk_cmp.comparison_value",
FT_INT8, BASE_DEC, NULL, 0x0, "", HFILL
}
},
@@ -142,7 +142,7 @@ void dissect_mac_mgmt_msg_clk_cmp_decoder(tvbuff_t *tvb, packet_info *pinfo _U_,
/* Get the tvb reported length */
tvb_len = tvb_reported_length(tvb);
/* display MAC payload type CLK_CMP */
- clk_cmp_item = proto_tree_add_protocol_format(tree, proto_mac_mgmt_msg_clk_cmp_decoder, tvb, offset, tvb_len, "Clock Comparision (CLK-CMP) (%u bytes)", tvb_len);
+ clk_cmp_item = proto_tree_add_protocol_format(tree, proto_mac_mgmt_msg_clk_cmp_decoder, tvb, offset, tvb_len, "Clock Comparison (CLK-CMP) (%u bytes)", tvb_len);
/* add MAC CLK_CMP subtree */
clk_cmp_tree = proto_item_add_subtree(clk_cmp_item, ett_mac_mgmt_msg_clk_cmp_decoder);
/* display the Message Type */
@@ -153,15 +153,15 @@ void dissect_mac_mgmt_msg_clk_cmp_decoder(tvbuff_t *tvb, packet_info *pinfo _U_,
clock_count = tvb_get_guint8(tvb, offset);
/* display the clock count */
proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_count, tvb, offset, 1, FALSE);
/* set the offset for clock comparision */
offset++;
for (i = 0; i < clock_count; i++ )
{ /* display the Clock ID */
proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_id, tvb, offset++, 1, FALSE);
/* display the sequence number */
proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_seq_number, tvb, offset++, 1, FALSE);
- /* display the comparision value */
- proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_comparision_value, tvb, offset++, 1, FALSE);
+ /* display the comparison value */
+ proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_comparison_value, tvb, offset++, 1, FALSE);
}
}
}
@@ -153,15 +153,15 @@ void dissect_mac_mgmt_msg_clk_cmp_decoder(tvbuff_t *tvb, packet_info *pinfo _U_,
/* display the clock count */
proto_tree_add_item(clk_cmp_tree, hf_clk_cmp_clock_count, tvb, offset, 1, FALSE);
- /* set the offset for clock comparision */
+ /* set the offset for clock comparison */
offset++;
for (i = 0; i < clock_count; i++ )